@@ -11,22 +11,13 @@
 
 
 position <- function(x) {
-  px <- attr(x, "position")
-  if (!is.null(px)) return(px) ## "position" exists
-  if (is.numeric(x)) return(x) ## numeric
-  if (!inherits(x, "factor")) stop("x must be either numeric or factor.")
-  lev.x <- levels(x)
-  if (inherits(x, "ordered")) {
-    on.exit(options(old.warn))
-    old.warn <- options(warn=-1)
-    if (!any(is.na(as.numeric(lev.x))))
-      x <- as.numeric(lev.x)  ## ordered with numeric levels
-    else
-      x <- seq(along=lev.x)  ## ordered with non-numeric levels
-  }
+  if(is.positioned(x))
+    attr(x, "position")
   else
-    x <- seq(along=lev.x) ## factor
-  x
+    if (inherits(x,  "factor"))
+      as.numeric(seq(along=levels(x)))
+    else
+      as.numeric(x)
 }
 
 unpositioned <- function(x, ...) {
@@ -44,14 +35,7 @@ is.numeric.positioned <- function(x, ...) { ## S-Plus
     NextMethod("is.numeric")
 }
 
-as.numeric.positioned <- function(x, ...) { ## S-Plus
-  if (is.numeric.positioned(x)) ## S-Plus doesn't dispatch.
-    x
-  else
-    position(x)[x]
-}
-
-as.double.positioned <- function(x, ...) { ## R
+as.position <- function(x) {
   if (is.numeric(x))
     x
   else
@@ -105,3 +89,6 @@ if.R(s=
      setOldClass(c("positioned", "ordered", "factor"))
      ,
      r={})
+
+
+## source("~/HH-R.package/HH/R/position.R")
